@@ -2,20 +2,23 @@ mod test_utils;
 
 #[cfg(feature = "compress")]
 mod d {
+    use chrono::{Local, NaiveDateTime};
+    use cond_sync::{CondSync, Other};
     use flate2::bufread::GzDecoder;
     use flexi_logger::{
         Cleanup, Criterion, DeferredNow, Duplicate, FileSpec, LogSpecification, Logger, Naming,
-        Record, WriteMode, TS_DASHES_BLANK_COLONS_DOT_BLANK,
+        WriteMode,
     };
     use glob::glob;
     use log::*;
-    use std::collections::BTreeMap;
-    use std::fs::File;
-    use std::io::{BufRead, BufReader, Write};
-    use std::ops::Add;
-    use std::path::{Path, PathBuf};
-    use std::thread::{self, JoinHandle};
-    use time::{format_description::FormatItem, macros::format_description, OffsetDateTime};
+    use std::{
+        collections::BTreeMap,
+        fs::File,
+        io::{BufRead, BufReader, Write},
+        ops::Add,
+        path::{Path, PathBuf},
+        thread::JoinHandle,
+    };
 
     const NO_OF_THREADS: usize = 5;
     const NO_OF_LOGLINES_PER_THREAD: usize = 20_000;
@@ -23,12 +26,11 @@ mod d {
     const NO_OF_LOG_FILES: usize = 2;
     const NO_OF_GZ_FILES: usize = 5;
 
+    // we use a special log line format that starts with a special string so that it is easier to
+    // verify that all log lines are written correctly
     #[test]
     fn multi_threaded() {
-        // we use a special log line format that starts with a special string so that it is easier to
-        // verify that all log lines are written correctly
-
-        let start = super::test_utils::now_local();
+        let start = Local::now();
         let directory = super::test_utils::dir();
         let end = {
             let logger = Logger::try_with_str("debug")
@@ -41,7 +43,7 @@ mod d {
             #[cfg(feature = "async")]
             let logger = logger.write_mode(WriteMode::Async);
 
-            let mut logger = logger
+            let logger = logger
                 .format(test_format)
                 .duplicate_to_stderr(Duplicate::Info)
                 .rotate(
@@ -50,42 +52,47 @@ mod d {
                     Cleanup::KeepLogAndCompressedFiles(NO_OF_LOG_FILES, NO_OF_GZ_FILES),
                 )
                 .start()
-                .unwrap_or_else(|e| panic!("Logger initialization failed with {}", e));
+                .unwrap_or_else(|e| panic!("Logger initialization failed with {e}"));
             info!(
                 "create a huge number of log lines with a considerable number of threads, \
              verify the log"
             );
 
-            let worker_handles = start_worker_threads(NO_OF_THREADS);
-            let new_spec = LogSpecification::parse("trace").unwrap();
-            thread::sleep(std::time::Duration::from_millis(500));
-            logger.set_new_spec(new_spec);
+            let cond_sync = CondSync::new(0_usize);
+            let worker_handles = start_worker_threads(NO_OF_THREADS, &cond_sync);
+            cond_sync
+                .wait_until(|value| *value == NO_OF_THREADS)
+                .unwrap();
+            logger.set_new_spec(LogSpecification::parse("trace").unwrap());
 
             wait_for_workers_to_close(worker_handles);
-            super::test_utils::now_local()
+            Local::now()
         };
-        let delta1 = (end - start).whole_milliseconds();
-        let delta2 = (super::test_utils::now_local() - end).whole_milliseconds();
+        let delta1_ms = end.signed_duration_since(start).num_milliseconds();
+        let delta2_ms = Local::now().signed_duration_since(end).num_milliseconds();
         println!(
-            "Task executed with {} threads in {} ms, \
-             program added {} ms to finish writing logs.",
-            NO_OF_THREADS, delta1, delta2
+            "Task executed with {NO_OF_THREADS} threads in {delta1_ms} ms, \
+             program added {delta2_ms} ms to finish writing logs.",
         );
 
         verify_logs(&directory.display().to_string());
     }
 
     // Starts given number of worker threads and lets each execute `do_work`
-    fn start_worker_threads(no_of_workers: usize) -> Vec<JoinHandle<u8>> {
+    fn start_worker_threads(
+        no_of_workers: usize,
+        cond_sync: &CondSync<usize>,
+    ) -> Vec<JoinHandle<u8>> {
         let mut worker_handles: Vec<JoinHandle<u8>> = Vec::with_capacity(no_of_workers);
-        trace!("Starting {} worker threads", no_of_workers);
+        trace!("Starting {no_of_workers} worker threads");
         for thread_number in 0..no_of_workers {
-            trace!("Starting thread {}", thread_number);
+            trace!("Starting thread {thread_number}");
+            let cond_sync_t = cond_sync.clone();
             worker_handles.push(
-                thread::Builder::new()
+                std::thread::Builder::new()
                     .name(thread_number.to_string())
                     .spawn(move || {
-                        do_work(thread_number);
+                        do_work(thread_number, cond_sync_t);
                         0
                     })
                     .unwrap(),
@@ -95,16 +102,16 @@ mod d {
         worker_handles
     }
 
-    fn do_work(thread_number: usize) {
-        trace!("({})     Thread started working", thread_number);
+    fn do_work(thread_number: usize, cond_sync: CondSync<usize>) {
+        trace!("({thread_number})     Thread started working");
         trace!("ERROR_IF_PRINTED");
+        cond_sync
+            .modify_and_notify(|value| *value += 1, Other::One)
+            .unwrap();
+
         for idx in 0..NO_OF_LOGLINES_PER_THREAD {
-            if idx % 1_000 == 0 {
-                std::thread::yield_now();
-            }
-            debug!("({})  writing out line number {}", thread_number, idx);
+            debug!("({thread_number})  writing out line number {idx}");
         }
-        std::thread::sleep(std::time::Duration::from_millis(500));
         trace!("MUST_BE_PRINTED");
     }
 
@@ -112,7 +119,7 @@ mod d {
         for worker_handle in worker_handles {
             worker_handle
                 .join()
-                .unwrap_or_else(|e| panic!("Joining worker thread failed: {:?}", e));
+                .unwrap_or_else(|e| panic!("Joining worker thread failed: {e:?}"));
         }
         trace!("All worker threads joined.");
     }
@@ -125,8 +132,8 @@ mod d {
         write!(
             w,
             "XXXXX [{}] T[{:?}] {} [{}:{}] {}",
-            now.format(TS_DASHES_BLANK_COLONS_DOT_BLANK),
-            thread::current().name().unwrap_or("<unnamed>"),
+            now.now().format("%Y-%m-%d %H:%M:%S%.6f %:z"),
+            std::thread::current().name().unwrap_or("<unnamed>"),
             record.level(),
             record.file().unwrap_or("<unnamed>"),
             record.line().unwrap_or(0),
@@ -138,7 +145,7 @@ mod d {
         let basename = String::from(directory).add("/").add(
             &std::path::Path::new(&std::env::args().next().unwrap())
             .file_stem().unwrap(/*cannot fail*/)
-            .to_string_lossy().to_string(),
+            .to_string_lossy(),
         );
 
         let mut counters = Counters {
@@ -157,15 +164,13 @@ mod d {
             // .add("_r[0-9][0-9]*.");
             .add("_r*.");
 
-        let log_pattern = fn_pattern.clone().add("log");
-        let no_of_log_files = glob(&log_pattern)
+        let no_of_log_files = glob(&fn_pattern.clone().add("log"))
             .unwrap()
             .map(Result::unwrap)
             .inspect(|p| inspect_file(p, &mut counters))
             .count();
 
-        let gz_pattern = fn_pattern.add("gz");
-        let no_of_gz_files = glob(&gz_pattern)
+        let no_of_gz_files = glob(&fn_pattern.add("gz"))
             .unwrap()
             .map(Result::unwrap)
             .inspect(|p| inspect_file(p, &mut counters))
@@ -192,14 +197,11 @@ mod d {
             Box::new(BufReader::new(File::open(p).unwrap()))
         };
 
-        const TS: &[FormatItem<'static>] = format_description!(
-            "[year]-[month]-[day] [hour]:[minute]:[second].[subsecond digits:6] \
-                [offset_hour sign:mandatory]:[offset_minute]"
-        );
+        const TS: &str = "%Y-%m-%d %H:%M:%S.%.6f %:z";
         for line in buf_reader.lines() {
             let line = line.unwrap();
             //9 fraction digits, should be 6
-            if let Ok(ts) = OffsetDateTime::parse(&line[7..40], &TS) {
+            if let Ok(ts) = NaiveDateTime::parse_from_str(&line[7..40], TS) {
                 let n = match &line[45..46].parse::<usize>() {
                     Ok(n) => *n,
                     Err(_) => continue,
@@ -209,7 +211,7 @@ mod d {
                     *counters
                         .total
                         .1
-                        .entry((ts - bts).whole_microseconds())
+                        .entry((ts - bts).num_microseconds().unwrap())
                         .or_insert(1) += 1;
                 }
                 counters.total.0 = Some(ts);
@@ -217,7 +219,7 @@ mod d {
                 if let Some(bts) = counters.threads[n].0 {
                     *counters.threads[n]
                         .1
-                        .entry((ts - bts).whole_microseconds())
+                        .entry((ts - bts).num_microseconds().unwrap())
                         .or_insert(1) += 1;
                 }
                 counters.threads[n].0 = Some(ts);
@@ -225,7 +227,7 @@ mod d {
         }
     }
 
-    fn write_csv(directory: &str, name: &str, data: &BTreeMap<i128, usize>) {
+    fn write_csv(directory: &str, name: &str, data: &BTreeMap<i64, usize>) {
         let mut path = PathBuf::from(directory);
         path.push(name);
         let mut file = std::io::BufWriter::new(
@@ -237,12 +239,12 @@ mod d {
                 .unwrap(),
         );
         for (interval, count) in data {
-            writeln!(file, "{:?};{};", interval, count).unwrap();
+            writeln!(file, "{interval:?};{count};").unwrap();
         }
     }
 
     struct Counters {
-        total: (Option<OffsetDateTime>, BTreeMap<i128, usize>),
-        threads: [(Option<OffsetDateTime>, BTreeMap<i128, usize>); 5],
+        total: (Option<NaiveDateTime>, BTreeMap<i64, usize>),
+        threads: [(Option<NaiveDateTime>, BTreeMap<i64, usize>); 5],
     }
 }
