@@ -1,3 +1,5 @@
+mod test_utils;
+
 use flexi_logger::DeferredNow;
 #[cfg(feature = "colors")]
 use flexi_logger::{colored_detailed_format, AdaptiveFormat};
@@ -10,7 +12,7 @@ fn test_recursion() {
     let logger = Logger::try_with_str("info")
         .unwrap()
         .format(detailed_format)
-        .log_to_file(FileSpec::default())
+        .log_to_file(FileSpec::default().directory(self::test_utils::dir()))
         .duplicate_to_stderr(Duplicate::All)
         .duplicate_to_stdout(Duplicate::All)
         .print_message();
@@ -23,16 +25,16 @@ fn test_recursion() {
         logger.adaptive_format_for_stdout(AdaptiveFormat::Custom(my_format, my_colored_format));
     logger
         .start()
-        .unwrap_or_else(|e| panic!("Logger initialization failed because: {}", e));
+        .unwrap_or_else(|e| panic!("Logger initialization failed because: {e}"));
 
     let dummy = Dummy();
 
     for _ in 0..10 {
-        error!("This is an error message for {}", dummy);
-        warn!("This is a warning for {}", dummy);
-        info!("This is an info message for {}", dummy);
-        debug!("This is a debug message for {}", dummy);
-        trace!("This is a trace message for {}", dummy);
+        error!("This is an error message for {dummy}");
+        warn!("This is a warning for {dummy}");
+        info!("This is an info message for {dummy}");
+        debug!("This is a debug message for {dummy}");
+        trace!("This is a trace message for {dummy}");
     }
 }
 
@@ -56,7 +58,7 @@ pub fn my_colored_format(
     record: &Record,
 ) -> Result<(), std::io::Error> {
     let level = record.level();
-    let style = ansi_term::Style::new().fg(ansi_term::Color::Fixed(165));
+    let style = nu_ansi_term::Style::new().fg(nu_ansi_term::Color::Fixed(165));
     write!(
         w,
         "{} [{}] {}",
